@@ -6,9 +6,9 @@
 #  Created by Alan D Snow, 2016.
 #  BSD 3-Clause
 
-from os import chdir
 from datetime import timedelta
 import logging
+import os
 
 from gazar.grid import GDALGrid
 
@@ -16,11 +16,13 @@ from .event import EventMode, LongTermMode
 from ..orm import (ProjectFile, WatershedMaskFile, ElevationGridFile,
                          MapTableFile)
 from ..lib import db_tools as dbt
+from ..util.context import tmp_chdir
 
 log = logging.getLogger(__name__)
 
+
 class GSSHAModel(object):
-    '''
+    """
     This class manages the generation and modification of
     models for GSSHA.
 
@@ -63,7 +65,7 @@ class GSSHAModel(object):
                         )
         model.write()
 
-    '''
+    """
     def __init__(self,
                  project_directory,
                  project_name=None,
@@ -76,29 +78,25 @@ class GSSHAModel(object):
                  land_use_grid=None,
                  land_use_grid_id=None,
                  land_use_to_roughness_table=None,
+                 load_rasters_to_db=True,
                  db_session=None,
                  project_manager=None,
                 ):
 
-        chdir(project_directory)
         self.project_directory = project_directory
         self.db_session = db_session
         self.project_manager = project_manager
+        self.load_rasters_to_db = load_rasters_to_db
 
         if project_manager is not None and db_session is None:
             raise ValueError("'db_session' is required to edit existing model if 'project_manager' is given.")
 
         if project_manager is None and db_session is None:
-            # Create Test DB
-            sqlalchemy_url, sql_engine = dbt.init_sqlite_memory()
-
-            # Create DB Sessions
-            self.db_session = dbt.create_session(sqlalchemy_url, sql_engine)
 
             if project_name is not None and mask_shapefile is None and elevation_grid_path is None:
-                # Instantiate GSSHAPY object for reading to database
-                self.project_manager = ProjectFile()
-                # Call read method
+                self.project_manager, db_sessionmaker = \
+                    dbt.get_project_session(project_name, self.project_directory)
+                self.db_session = db_sessionmaker()
                 self.project_manager.readInput(directory=self.project_directory,
                                                projectFileName="{0}.prj".format(project_name),
                                                session=self.db_session)
@@ -108,8 +106,10 @@ class GSSHAModel(object):
                     raise ValueError("Need to set project_name, mask_shapefile, "
                                      "and elevation_grid_path to generate "
                                      "a new GSSHA model.")
-                # Instantiate GSSHAPY object for reading to database
-                self.project_manager = ProjectFile(name=project_name, map_type=0)
+
+                self.project_manager, db_sessionmaker = \
+                    dbt.get_project_session(project_name, self.project_directory, map_type=0)
+                self.db_session = db_sessionmaker()
                 self.db_session.add(self.project_manager)
                 self.db_session.commit()
 
@@ -149,33 +149,37 @@ class GSSHAModel(object):
                                    )
 
     def set_mask_from_shapefile(self, shapefile_path, cell_size):
-        '''
+        """
         Adds a mask from a shapefile
-        '''
+        """
+        # make sure paths are absolute as the working directory changes
+        shapefile_path = os.path.abspath(shapefile_path)
         # ADD MASK
-        mask_name = '{0}.msk'.format(self.project_manager.name)
-        msk_file = WatershedMaskFile(project_file=self.project_manager,
-                                     session=self.db_session)
+        with tmp_chdir(self.project_directory):
+            mask_name = '{0}.msk'.format(self.project_manager.name)
+            msk_file = WatershedMaskFile(project_file=self.project_manager,
+                                         session=self.db_session)
 
-        msk_file.generateFromWatershedShapefile(shapefile_path,
-                                                cell_size=cell_size,
-                                                out_raster_path=mask_name,
-                                                )
+            msk_file.generateFromWatershedShapefile(shapefile_path,
+                                                    cell_size=cell_size,
+                                                    out_raster_path=mask_name,
+                                                    load_raster_to_db=self.load_rasters_to_db)
 
     def set_elevation(self, elevation_grid_path, mask_shapefile):
-        '''
+        """
         Adds elevation file to project
-        '''
+        """
         # ADD ELEVATION FILE
         ele_file = ElevationGridFile(project_file=self.project_manager,
                                      session=self.db_session)
         ele_file.generateFromRaster(elevation_grid_path,
-                                    mask_shapefile)
+                                    mask_shapefile,
+                                    load_raster_to_db=self.load_rasters_to_db)
 
     def set_outlet(self, latitude, longitude, outslope):
-        '''
+        """
         Adds outlet point to project
-        '''
+        """
         self.project_manager.setOutlet(latitude=latitude, longitude=longitude,
                                        outslope=outslope)
 
@@ -184,21 +188,25 @@ class GSSHAModel(object):
                       land_use_grid=None,
                       land_use_grid_id=None,
                       land_use_to_roughness_table=None):
-        '''
+        """
         ADD ROUGHNESS FROM LAND COVER
         See: http://www.gsshawiki.com/Project_File:Overland_Flow_%E2%80%93_Required
-        '''
+        """
         if roughness is not None:
             self.project_manager.setCard('MANNING_N', str(roughness))
         elif land_use_grid is not None and (land_use_grid_id is not None \
                 or land_use_to_roughness_table is not None):
+            # make sure paths are absolute as the working directory changes
+            land_use_grid = os.path.abspath(land_use_grid)
+            if land_use_to_roughness_table is not None:
+                land_use_to_roughness_table = os.path.abspath(land_use_to_roughness_table)
+
             mapTableFile = MapTableFile(project_file=self.project_manager)
             mapTableFile.addRoughnessMapFromLandUse("roughness",
                                                     self.db_session,
                                                     land_use_grid,
                                                     land_use_to_roughness_table=land_use_to_roughness_table,
-                                                    land_use_grid_id=land_use_grid_id,
-                                                    )
+                                                    land_use_grid_id=land_use_grid_id)
         else:
             raise ValueError("Need to either set 'roughness', or need "
                              "to set values from land use grid ...")
@@ -211,9 +219,9 @@ class GSSHAModel(object):
                   rain_duration=timedelta(seconds=30*60),
                   event_type='EVENT',
                  ):
-        '''
+        """
         Initializes event for GSSHA model
-        '''
+        """
         # ADD TEMPORTAL EVENT INFORMAITON
         if event_type == 'LONG_TERM':
             self.event = LongTermMode(self.project_manager,
@@ -234,9 +242,9 @@ class GSSHAModel(object):
                                                 duration=rain_duration)
 
     def write(self):
-        '''
+        """
         Write project to directory
-        '''
+        """
         # write data
         self.project_manager.writeInput(session=self.db_session,
                                         directory=self.project_directory,
